@@ -117,6 +117,8 @@ sub reconnect {
 
 =head2 topic
 
+=head2 kick
+
 =head2 w
 
 =head2 whois
@@ -124,6 +126,7 @@ sub reconnect {
 =cut
 
 sub join  {"JOIN $_[1]"}
+sub kick  {"KICK $_[2]->{target} $_[1]"}
 sub list  {"LIST"}
 sub me    {"PRIVMSG $_[2]->{target} :\x{1}ACTION $_[1]\x{1}"}
 sub mode  {"MODE $_[1]"}
