@@ -1,5 +1,5 @@
 ;(function($) {
-  window.convos = window.convos || {}
+  window.convos = window.convos || {};
 
   convos.conversations = {
     add: function($e) {
@@ -21,4 +21,18 @@
       }
     }
   };
+
+  $(document).ready(function() {
+    var pos = 0;
+    var t;
+    $(window)
+      .on('blur', function() {
+        if (!pos) pos = $('div.messages li').length;
+        clearTimeout(t);
+      })
+      .on('focus', function() {
+        t = setTimeout(function() { pos = 0; }, 10000);
+        $('div.messages li').removeClass('history-starting-point').eq(pos).addClass('history-starting-point');
+      });
+  });
 })(jQuery);
